@@ -4,7 +4,7 @@ package Test::Class::Moose::Executor::Parallel;
 
 use 5.10.0;
 
-our $VERSION = '0.75';
+our $VERSION = '0.76';
 
 use Moose 2.0000;
 use Carp;
@@ -17,7 +17,7 @@ use Test2::IPC;
 use List::SomeUtils qw( none part );
 use Parallel::ForkManager;
 use Scalar::Util qw(reftype);
-use TAP::Formatter::Color;
+use TAP::Formatter::Color 3.29;
 use Test2::API qw( test2_stack );
 use Test2::AsyncSubtest 0.000018 ();
 use Test::Class::Moose::AttributeRegistry;
@@ -200,7 +200,7 @@ Test::Class::Moose::Executor::Parallel - Execute tests in parallel (parallelized
 
 =head1 VERSION
 
-version 0.75
+version 0.76
 
 =for Pod::Coverage Tags Tests runtests
 
